from nltk import PorterStemmer

from sklearn.feature_extraction.text import TfidfVectorizer


def get_content_from_book(book, excluded_chapters=False):
    book_contents = ''
    for chapter in book.chapter_set.exclude(id__in=excluded_chapters):
        book_contents = book_contents + chapter.name
        if chapter.content:
            book_contents = book_contents + chapter.content
    return book_contents.split(' ')


def calculate_book_similarity(book1, book2, excluded_chapters=None,
                              max_features=13):
    if excluded_chapters:
        book1_contents = get_content_from_book(
            book1,
            excluded_chapters['book1_excluded'],
        )
        book2_contents = get_content_from_book(
            book2,
            excluded_chapters['book2_excluded'],
        )
    else:
        book1_contents = get_content_from_book(book1)
        book2_contents = get_content_from_book(book2)

    stemmer = PorterStemmer()
    stemmed1 = ' '.join([str(stemmer.stem(token)) for token in book1_contents])
    stemmed2 = ' '.join([str(stemmer.stem(token)) for token in book2_contents])

    vect = TfidfVectorizer(
        stop_words='english', analyzer='word', max_features=max_features)
    tfidf = vect.fit_transform([stemmed1, stemmed2])

    return {
        'res': (tfidf * tfidf.T).A[0][1],
        'terms': dict(zip(vect.get_feature_names(), vect.idf_)),
    }
