from django.db import models
from django.utils import timezone

from course_inspector.books.o_reilly import get_o_reilly_content
from course_inspector.books.pearson import get_pearson_content


class Publisher(models.Model):
    name = models.CharField(max_length=255)
    publisher_id = models.CharField(max_length=255)

    class Meta:
        ordering = ['name']

    def __str__(self):
        return self.name


class Book(models.Model):
    isbn = models.CharField(
        primary_key=True,
        max_length=32,
        unique=True,
        help_text='Must be ISBN13. Ten-digit ISBNs can be expressed as '
                  '13-digit ones starting with 978'
    )

    title = models.CharField(max_length=255)
    created_at = models.DateTimeField()
    publisher = models.ForeignKey(Publisher)

    def __str__(self):
        return self.title

    def save(self, *args, **kwargs):
        self.isbn = self.isbn.replace("-", "")
        if self.created_at is None:
            self.created_at = timezone.now()
        super().save(*args, **kwargs)
        if self.publisher.publisher_id == 'pearson':
            get_pearson_content(self, Chapter)
        if self.publisher.publisher_id == 'oreilly':
            get_o_reilly_content(self, Chapter)


class Chapter(models.Model):
    book = models.ForeignKey(Book)
    name = models.CharField(max_length=255)
    number = models.IntegerField()
    content = models.TextField(max_length=2048, blank=True, null=True)

    def __str__(self):
        return '{}, chapter {}'.format(self.book.title, self.number)
