import re

from bs4 import BeautifulSoup

import requests


def get_book_url(isbn):
    url = 'https://ssearch.oreilly.com/?q={}'
    html = requests.get(url.format(isbn.replace("-", ""))).content
    soup = BeautifulSoup(html, 'html.parser')
    result = soup.findAll('div', {'class': 'product-result'})[0]
    return result.find('a', {'class': 'learn-more'})['href']


def get_toc(url):
    html = requests.get(url).content
    soup = BeautifulSoup(html, 'html.parser')
    return soup.find('ol', {'id': 'chapters'})


def get_chapters_from_toc(toc_html):
    res = []
    chapters = toc_html.findAll('li', {'class': 'chapter'})
    for c in chapters:
        chapter = {}

        chapter_tag = None
        if c.find('h4').text.replace(' ', '').startswith('Chapter'):
            chapter_tag = 'h4'
        else:
            chapter_tag = 'h3'

        if not hasattr(c.find(chapter_tag), 'text'):
            continue

        chapter_number = re.findall(
            r'(?:Chapter )(\d{0,2})', c.find(chapter_tag).text)
        if len(chapter_number) <= 0:
            continue
        chapter['number'] = chapter_number[0]
        c.find('span', {'class': 'chapter-label'}).extract()
        chapter['name'] = c.find('h4').text
        chapter['content'] = ' '.join(map(
            lambda x: x.get_text(), c.find('ol').findAll('li')
        ))
        res.append(chapter)
    return res


def get_o_reilly_content(book, Chapter):  # noqa
    book_url = get_book_url(book.isbn)
    toc_html = get_toc(book_url)
    chapters = get_chapters_from_toc(toc_html)
    for chapter in chapters:
        Chapter(
            book=book,
            name=chapter['name'],
            number=chapter['number'],
            content=chapter['content']
        ).save()
