import json

from django.shortcuts import render

from rest_framework import decorators, response, viewsets

from course_inspector.books.book_analyzer import calculate_book_similarity
from course_inspector.books.models import Book
from course_inspector.books.serializers import BookSerializer


class BookAPIViewSet(viewsets.ModelViewSet):
    queryset = Book.objects.all()
    serializer_class = BookSerializer

    @decorators.detail_route(url_path='compare/(?P<compare_pk>[0-9]+)')
    def compare(self, request, pk=None, compare_pk=None):
        book1 = Book.objects.get(pk=pk)
        book2 = Book.objects.get(pk=compare_pk)

        similarity = calculate_book_similarity(book1, book2)

        return response.Response(data={'book1': book2.title,
                                       'book2': book1.title,
                                       'similarity': similarity,
                                       })

    @decorators.detail_route(
        url_path='compare/(?P<compare_pk>[0-9]+)/compare_graph')
    def compare_graph(self, request, pk=None, compare_pk=None):
        book1 = Book.objects.get(pk=pk)
        book2 = Book.objects.get(pk=compare_pk)

        similarities = []
        for max_features in range(1, 101):
            similarities.append({
                'x': max_features,
                'y': calculate_book_similarity(
                    book1, book2, max_features=max_features)['res'],
            })

        return response.Response(data={'book2': book2.title,
                                       'book1': book1.title,
                                       'result': similarities,
                                       })

    @decorators.detail_route(
        url_path='compare/(?P<compare_pk>[0-9]+)/compare_graph/draw')
    def draw(self, request, pk=None, compare_pk=None):
        book1 = Book.objects.get(pk=pk)
        book2 = Book.objects.get(pk=compare_pk)

        similarities = []
        for max_features in range(1, 101):
            similarities.append({
                'x': max_features,
                'y': calculate_book_similarity(
                    book1, book2, max_features=max_features)['res'],
            })
        return render(request,
                      'graph.html',
                      {'data': json.dumps(similarities)})
