# -*- coding: utf-8 -*-
import re

from django.core.management import BaseCommand
from django.db import IntegrityError

import requests

from course_inspector.courses.models import Course, University


black_listed_courses = []

black_listed_study_programmes = []

api_key = 'b19fcde05baa3b1405357b840cc14a37'

courses = {}


class Command(BaseCommand):
    help = 'Scrapes the Waterloo API for courses'

    def handle(self, *args, **options):
        r = requests.get('https://api.uwaterloo.ca/v2/courses.json?key=' +
                         api_key)
        data = r.json()

        # Make dict with course name:course_id pairs (MATH 122: 00723)
        for course in data['data']:
            key = course.get('subject') + course.get('catalog_number')
            course_id = course.get('course_id')
            courses[key] = course_id

        for course in courses:
            process_course(courses.get(course))


def process_course(code):
    try:
        return Course.objects.get(external_id=code)
    except Course.DoesNotExist:
        pass

    if code in black_listed_courses:
        return None
    if any(blacklist_course in code for blacklist_course in
           black_listed_study_programmes):
        return None

    waterloo, created = University.objects.get_or_create(
        short_name='waterloo',
        name="University of Waterloo",
    )

    print("Working on " + code)
    r = requests.get('https://api.uwaterloo.ca/v2/courses/' + code + '.json' +
                     '?key=' + api_key)
    data = r.json()['data']

    if not data:
        print("No course data found for {}".format(code))
        return None

    new_course = Course()

    if 'course_id' not in data:
        print("Course missing code")
        return None
    new_course.external_id = data.get('course_id')

    new_course.course_id = data.get('subject') + data.get('catalog_number')

    if 'title' in data:
        new_course.name = data.get('title')
    else:
        print("Course missing title")

    if 'units' in data:
        new_course.credits = data.get('units')
    else:
        print("Course missing credit")

    if 'subject' in data:
        new_course.meta_subject_area = data.get('subject')
    else:
        print("Course missing subject")

    if 'academic_level' in data:
        new_course.meta_study_level_name = data.get('academic_level')
    else:
        print("Course missing academic_level")

    if 'description' in data:
        new_course.meta_course_content = data.get('description')

    if 'notes' in data:
        new_course.meta_learning_methods = data.get('notes')

    if 'url' in data:
        new_course.meta_e_url = data.get('url')

    new_course.semester = data.get('calendar_year', '').lower()
    new_course.university = waterloo

    if 'prerequisites' in data and data.get('prerequisites') is not None:
        prereqs_ids = []
        # PHYS 112 or 122; MATH 114 or 136;
        # print(data.get('prerequisites'))
        prereqs = data.get('prerequisites').split(';')
        prereqs_split = list(filter(None, prereqs))  # Remove empty elements
        # ['PHYS 112 or 122', ' MATH 114 or 136']
        for prereq_area in prereqs_split:
            # print(prereq_area)
            subject_area = re.findall('[A-Z]{2,6}', prereq_area)
            # ['PHYS']
            catalog_number = re.findall('\d{3}[A-Z]?', prereq_area)
            # ['128', '138', '148']
            if subject_area and catalog_number:
                for s in subject_area:
                    for c in catalog_number:
                        prereqs_ids.append(courses.get(s+c))

        print(prereqs_ids)
        fork_type = 'recommended'

        for new_child in prereqs_ids:
            if new_child == new_course.external_id:
                continue
            if new_child is not None:
                child = process_course(new_child)
                if child:
                    try:
                        new_course.add_child(child, type=fork_type)
                    except IntegrityError:
                        print("Child {} already registered".format(
                            child.external_id))

    else:
        print('This course has no prerequisites')

    print('\t\t\t\tFinished processing {}\n\n\n'.format(
        new_course.external_id))
    try:
        new_course.save()
    except IntegrityError:
        print('Course already exists')

    return new_course
