# Course Inspector

[![Build Status](https://travis-ci.com/andrroy/master.svg?token=EW9VKVgzsyk1aGq5ThsN&branch=travisci)](https://travis-ci.com/andrroy/master)

This is the source for the Course Inspector API, a collection of tools for comparing university courses.


## Documentation

### First time setup

1. Make sure you have the following system dependencies installed:

   - Python 3.5 (including development headers)
   - virtualenv
   - PostgreSQL (including development headers)
   - (PostGIS)

   On Ubuntu/Debian:

   ```
   sudo apt install python3.5-dev virtualenv \
       postgresql-9.5 postgresql-server-dev-9.5 postgis
   ```

   On OS X:

   ```
   brew install python3 postgresql postgis
   ```

2. Create and activate a virtualenv:

   ```
   virtualenv -p /usr/bin/python3.5 env
   source env/bin/activate
   ```

   Make sure to run the commands outside the project folder, as the resulting
   `venv` folder in the project will interfere with running the tests as
   described below.  Alternatively you can use `virtualenwrapper` to handle
   the virtualenvs for you.

   ```
   mkvirtualenv -a . --python python3.5 courseinspector
   ```

   Then when you want to work on the Course Inspector project, you can just run
   `workon courseinspector`, and you will be sent to the project folder, and the
   virtualenv will be activated for you.

3. Install requirements inside the virtualenv:

   ```
   pip install --upgrade -r requirements.txt
   ```

4. Create a local PostgreSQL database and credentials:

   First we create a user:

   ```
   sudo -u postgres createuser -d -E -l -P courseinspector
   ```

   The `-d` flag (create DB permissions) is needed for Django to recreate the
   test database on each run of the test suite. You will be prompted for a
   password for the user.

   Then we create the database:

   ```
   sudo -u postgres createdb -E UTF-8 -T template0 -O courseinspector courseinspector
   ```

   You should now be able to login with the created credentials. You can test
   this by running:

   ```
   psql -h localhost -U courseinspector courseinspector
   ```

5. Set local environment variables:

   Copy the `dev-template.env` template file to `.env`.

   Set the credentials and address of your local PostgreSQL server to use it
   instead of the default SQLite database.

   ```
   DATABASE_URL=postgres://<user>:<password>@localhost:5432/<dbname>
   ```

6. Run database migrations to populate your database:

   ```
   python manage.py migrate
   ```

   You'll have to rerun this command every time the database schema changes.

6. To create an admin user, run the server (see below), and then do:

   ```
   python manage.py createsuperuser
   ```

   Your user should now have full access to your local instance of Course Inspector.

