import React from 'react';
import { connect } from 'react-redux';

import Col from 'react-bootstrap/lib/Col';
import Row from 'react-bootstrap/lib/Row';
import Panel from 'react-bootstrap/lib/Panel';

import { createStructuredSelector } from 'reselect';
import { selectCompareCourses } from './selectors';

const DescriptionTab = (props) => {
  const { loading, course1, course2 } = props;

  if (loading) {
    return (<span>Loading</span>);
  }

  return (
    <div style={{ paddingTop: '1.5rem' }}>
      <Row>
        <Col xs={12} sm={6} smOffset={0}>
          <Panel header="Description">
            { course1.meta_course_content ?
              <p>{course1.meta_course_content}</p> :
              <p style={{ color: 'grey', fontSize: '15px' }}>This course has no description specified</p>
            }
          </Panel>
        </Col>

        <Col xs={12} sm={6} smOffset={0}>
          <Panel header="Description">
            { course2.meta_course_content ?
              <p>{course2.meta_course_content}</p> :
              <p style={{ color: 'grey', fontSize: '15px' }}>This course has no description specified</p>
            }
          </Panel>
        </Col>
      </Row>

      <Row>
        <Col xs={12} sm={6} smOffset={0}>
          <Panel header="Learning objectives">
            { course1.meta_goals ?
              <p>{course1.meta_goals}</p> :
              <p style={{ color: 'grey', fontSize: '15px' }}>This course has no learning objectives specified</p>
            }
          </Panel>
        </Col>

        <Col xs={12} sm={6} smOffset={0}>
          <Panel header="Learning objectives">
            { course2.meta_goals ?
              <p>{course2.meta_goals}</p> :
              <p style={{ color: 'grey', fontSize: '15px' }}>This course has no learning objectives specified</p>
            }
          </Panel>
        </Col>
      </Row>

      <Row>
        <Col xs={12} sm={6} smOffset={0}>
          <Panel header="Activities">
            { course1.meta_learning_methods ?
              <p>{course1.meta_learning_methods}</p> :
              <p style={{ color: 'grey', fontSize: '15px' }}>This course has no activities specified</p>
            }
          </Panel>
        </Col>

        <Col xs={12} sm={6} smOffset={0}>
          <Panel header="Activities">
            { course2.meta_learning_methods ?
              <p>{course2.meta_learning_methods}</p> :
              <p style={{ color: 'grey', fontSize: '15px' }}>This course has no activities specified</p>
            }
          </Panel>
        </Col>
      </Row>
    </div>
  );
};

DescriptionTab.propTypes = {
  course1: React.PropTypes.object,
  course2: React.PropTypes.object,
  loading: React.PropTypes.bool,
};

const mapStateToProps = createStructuredSelector({
  course: selectCompareCourses(),
});

export default connect(mapStateToProps)(DescriptionTab);
