import React from 'react';
import { connect } from 'react-redux';

import { Link } from 'react-router';

import Col from 'react-bootstrap/lib/Col';
import Row from 'react-bootstrap/lib/Row';
import Panel from 'react-bootstrap/lib/Panel';
import Table from 'react-bootstrap/lib/Table';

import { createStructuredSelector } from 'reselect';
import { selectCompareCourses } from './selectors';


const SummaryTab = (props) => {
  const { loading, course1, course2 } = props;
  const university1 = course1.university || {};
  const university2 = course2.university || {};

  const urlparser1 = document.createElement('a');
  urlparser1.href = course1.meta_e_url;

  const urlparser2 = document.createElement('a');
  urlparser2.href = course2.meta_e_url;

  if (loading) {
    return (<span>Loading</span>);
  }

  return (
    <div style={{ paddingTop: '1.5rem' }}>
      <Row>
        <Col xs={12} sm={6} smOffset={0}>
          <Panel header="General">
            <Table responsive>
              <tbody>
                <tr>
                  <th>Course code</th>
                  <td>
                    <Link to={`/course/${course1.university}/${course1.course_id}`}>
                      {course1.course_id}
                    </Link>
                  </td>
                </tr>
                <tr>
                  <th>Course name</th>
                  <td>{course1.name}</td>
                </tr>
                <tr>
                  <th>Credits</th>
                  <td>{course1.credits}</td>
                </tr>
                <tr>
                  <th>Level</th>
                  <td>{course1.meta_study_level_name}</td>
                </tr>
                <tr>
                  <th>University</th>
                  <td>{university1.name}</td>
                </tr>
                <tr>
                  <th>Semester</th>
                  <td>{course1.semester}</td>
                </tr>
                <tr>
                  <th>External URL</th>
                  <td>
                    <a href={`${course1.meta_e_url}`} target="_blank">{course1.course_id} at {urlparser1.hostname}</a>
                  </td>
                </tr>
              </tbody>
            </Table>
          </Panel>
        </Col>

        <Col xs={12} sm={6} smOffset={0}>
          <Panel header="General">
            <Table responsive>
              <tbody>
                <tr>
                  <th>Course code</th>
                  <td>
                    <Link to={`/course/${course2.university}/${course2.course_id}`}>
                      {course2.course_id}
                    </Link>
                  </td>
                </tr>
                <tr>
                  <th>Course name</th>
                  <td>{course2.name}</td>
                </tr>
                <tr>
                  <th>Credits</th>
                  <td>{course2.credits}</td>
                </tr>
                <tr>
                  <th>Level</th>
                  <td>{course2.meta_study_level_name}</td>
                </tr>
                <tr>
                  <th>University</th>
                  <td>{university2.name}</td>
                </tr>
                <tr>
                  <th>Semester</th>
                  <td>{course2.semester}</td>
                </tr>
                <tr>
                  <th>External URL</th>
                  <td>
                    <a href={`${course2.meta_e_url}`} target="_blank">{course2.course_id} at {urlparser2.hostname}</a>
                  </td>
                </tr>
              </tbody>
            </Table>
          </Panel>
        </Col>
      </Row>
    </div>
  );
};

SummaryTab.propTypes = {
  course1: React.PropTypes.object,
  course2: React.PropTypes.object,
  loading: React.PropTypes.bool,
};

const mapStateToProps = createStructuredSelector({
  course: selectCompareCourses(),
});

export default connect(mapStateToProps)(SummaryTab);
