import React, { Component } from 'react';
import { connect } from 'react-redux';
import { createStructuredSelector } from 'reselect';

import Grid from 'react-bootstrap/lib/Grid';
import Row from 'react-bootstrap/lib/Row';
import Tab from 'react-bootstrap/lib/Tab';
import Col from 'react-bootstrap/lib/Col';
import Tabs from 'react-bootstrap/lib/Tabs';
import Panel from 'react-bootstrap/lib/Panel';
import Button from 'react-bootstrap/lib/Button';
import PageHeader from 'react-bootstrap/lib/PageHeader';

import { loadCompareCourses, requestAddApproved } from './actions';

import {
  selectCompareCourses,
} from './selectors';
import selectAuthWrapper from '../AuthWrapper/selectors';

import NotFoundPage from 'containers/NotFoundPage';
import SummaryTab from './SummaryTab';
import DescriptionTab from './DescriptionTab';

class CourseDetails extends Component {
  constructor() {
    super();
    this.state = { activeTab: 1 };
  }

  componentDidMount() {
    this.props.dispatch(loadCompareCourses(this.props.params.id1, this.props.params.id2));
  }

  handleApprove() {
    this.props.dispatch(requestAddApproved(this.props.params.id1, this.props.params.id2));
  }

  render() {
    const {
      error,
      requestingAddApprovedSuccess,
      course1,
      course2,
      similarity
    } = this.props.compareCourses;

    if (error) {
      return (<NotFoundPage />);
    }

    return (
      <Grid>
        <Row>
          <Col sm={4} smOffset={4}>
            <PageHeader style={{ borderBottom: 'none' }}>
              {course1.course_id} vs {course2.course_id}
            </PageHeader>
          </Col>
        </Row>
        <Row>
          <Col sm={4}>
            <Panel header="Suggested similarity">
              <h4>Similarity: {parseFloat(similarity.overall_similarity * 100).toFixed(2)}%</h4>
            </Panel>
          </Col>
          <Col sm={3} smOffset={4}>
            {this.props.user.admin &&
              <div>
                {
                  requestingAddApprovedSuccess
                  ?
                    <h3>Course link approved</h3>
                  :
                    <Button
                      onClick={(event) => this.handleApprove(event)}
                      className="btn btn-primary btn-lg btn-block"
                      style={{ height: '100px' }}
                    >
                      Approve course link
                    </Button>
                }
              </div>
            }
          </Col>
        </Row>
        <Row>
          <Tabs
            activeKey={this.state.activeTab}
            onSelect={(t) => this.setState({ activeTab: t })}
            id="tablist"
          >
            <Tab eventKey={1} title="Summary">
              <SummaryTab course1={course1 || []} course2={course2 || []} />
            </Tab>
            <Tab eventKey={2} title="Description">
              <DescriptionTab course1={course1 || []} course2={course2 || []} />
            </Tab>
            <Tab eventKey={3} title="Curriculum">

            </Tab>
          </Tabs>
        </Row>
      </Grid>
    );
  }
}

CourseDetails.propTypes = {
  params: React.PropTypes.object,
  dispatch: React.PropTypes.func,
  compareCourses: React.PropTypes.object,
  user: React.PropTypes.object,
};

const mapStateToProps = createStructuredSelector({
  compareCourses: selectCompareCourses(),
  user: selectAuthWrapper(),
});

export default connect(mapStateToProps)(CourseDetails);
