import { takeLatest } from 'redux-saga';
import { take, call, put } from 'redux-saga/effects';

import api from 'utils/api';

import {
  LOAD_COMPARE_COURSES,
  REQUEST_ADD_APPROVED,
  REQUEST_REMOVE_APPROVED,
} from './constants';
import {
  compareCoursesLoaded,
  compareCoursesError,
  requestAddApprovedSuccess,
  requestAddApprovedFailure,
  requestRemoveApprovedFailure,
  requestRemoveApprovedSuccess,
} from './actions';

// Course
export function* getComparisonResult({ id1, id2 }) {
  const res = yield call(api.getCompareResult, id1, id2);
  if (res.err) {
    return yield put(compareCoursesError());
  }
  return yield put(compareCoursesLoaded(res.data.course1, res.data.course2, res.data.similarity));
}

export function* getCourseWatcher() {
  yield takeLatest(LOAD_COMPARE_COURSES, getComparisonResult);
}

// Approved
export function* addApproved({ from, to }) {
  const res = yield call(api.addApproved, from, to);
  if (res.err) {
    return yield put(requestAddApprovedFailure());
  }
  return yield put(requestAddApprovedSuccess(from));
}

export function* addApprovedWatcher() {
  const action = yield take(REQUEST_ADD_APPROVED);
  yield call(addApproved, action);
}

export function* removeApproved({ from, to }) {
  const res = yield call(api.removeApproved, from, to);
  if (res.err) {
    return yield put(requestRemoveApprovedFailure());
  }
  return yield put(requestRemoveApprovedSuccess(from));
}

export function* removeApprovedWatcher() {
  const action = yield take(REQUEST_REMOVE_APPROVED);
  yield call(removeApproved, action);
}


export default [
  getCourseWatcher,
  addApprovedWatcher,
  removeApprovedWatcher,
];
