import React, { Component, PropTypes } from 'react';
import { connect } from 'react-redux';
import { push } from 'react-router-redux';

import Grid from 'react-bootstrap/lib/Grid';
import Row from 'react-bootstrap/lib/Row';
import Col from 'react-bootstrap/lib/Col';
import Button from 'react-bootstrap/lib/Button';
import FormGroup from 'react-bootstrap/lib/FormGroup';
import ControlLabel from 'react-bootstrap/lib/ControlLabel';
import Alert from 'react-bootstrap/lib/Alert';

import { createStructuredSelector } from 'reselect';

import CourseSearch from 'containers/CourseSearch';

export class CompareDirectly extends Component {
  constructor() {
    super();
    this.state = {
      selectedCourse1: null,
      selectedCourse2: null,
      selectionError: false,
    };
  }

  handleCourseChange(courseNumber, course) {
    if (courseNumber === 1) {
      this.setState({ selectedCourse1: course });
    } else {
      this.setState({ selectedCourse2: course });
    }
  }

  handleSubmit(event) {
    event.preventDefault();

    const course1 = this.state.selectedCourse1;
    const course2 = this.state.selectedCourse2;

    if (!course1 || !course2) {
      return this.setState({ selectionError: true });
    }

    return this.props.dispatch(push(
      `/course/${course1.id}/compare/${course2.id}`
    ));
  }

  render() {
    return (
      <Grid>
        <Row>
          <Col xs={10} xsOffset={1} sm={8} smOffset={2} md={6} mdOffset={3} >
            <h3>Compare courses</h3>
            <br />
            { this.state.selectionError &&
              <Alert bsStyle="danger">
                <stong>No course selected</stong>
              </Alert>
            }

            <form onSubmit={(event) => this.handleSubmit(event)}>
              <ControlLabel>First course</ControlLabel>
              <FormGroup>
                <CourseSearch handleChange={(course) => this.handleCourseChange(1, course)} />
              </FormGroup>
              <ControlLabel>Second course</ControlLabel>
              <FormGroup>
                <CourseSearch handleChange={(course) => this.handleCourseChange(2, course)} />
              </FormGroup>
              <Button
                className="center-block"
                bsStyle="primary"
                bsSize="large"
                type="submit"
                block
              >
                Compare
              </Button>
            </form>

          </Col>
        </Row>
      </Grid>
    );
  }
}

CompareDirectly.propTypes = {
  dispatch: PropTypes.func,
};

const mapStateToProps = createStructuredSelector({

});

export default connect(mapStateToProps)(CompareDirectly);
