import React, { PropTypes } from 'react';

import Panel from 'react-bootstrap/lib/Panel';
import Table from 'react-bootstrap/lib/Table';
import Button from 'react-bootstrap/lib/Button';


const getPanelFooter = () => (
  <div className="text-right">
    <Button disabled>Add curriculum</Button>
  </div>
);


const CurriculumTab = ({ curriculum }) => (
  <div style={{ paddingTop: '1rem' }}>
    <Panel header="Curriculum" footer={getPanelFooter()}>
      {
        curriculum.length > 0 ?
          <Table responsive>
            <thead>
              <tr>
                <th>Title</th>
                <th>Publisher</th>
                <th>ISBN</th>
                <th>Excluded chapters</th>
              </tr>
            </thead>
            <tbody>
              {curriculum.map((c, key) => (
                <tr key={key}>
                  <td>{c.book.title}</td>
                  <td>{c.publisher}</td>
                  <td>{c.isbn}</td>
                  <td>
                    {c.excluded_chapters.map((chapter, k) =>
                      <span key={k}>{chapter},</span>)}
                  </td>
                </tr>
              ))}
            </tbody>
          </Table>
          :
          <h5 className="text-center" style={{ color: 'grey' }}>No curriculum available</h5>
      }
    </Panel>
  </div>
);

CurriculumTab.propTypes = {
  curriculum: PropTypes.array,
};

export default CurriculumTab;
