import React, { Component } from 'react';
import { connect } from 'react-redux';

import Col from 'react-bootstrap/lib/Col';
import Row from 'react-bootstrap/lib/Row';
import Panel from 'react-bootstrap/lib/Panel';
import Table from 'react-bootstrap/lib/Table';

import Spinner from 'components/Spinner';
import PreReqTable from './PreReqTable';
import EditCourse from './EditCourse';

import commonStyles from 'styles/commons.css';
import { createStructuredSelector } from 'reselect';
import { selectCourse, selectCourseLoading } from './selectors';
import selectAuthWrapper from '../AuthWrapper/selectors';


class GeneralTab extends Component {
  constructor() {
    super();
    this.state = { imageLoaded: false };
  }

  handleImageLoaded() {
    this.setState({ imageLoaded: true });
  }

  render() {
    const { loading, course, user } = this.props;
    const university = course.university || {};
    const isGraphLoaded = this.state.imageLoaded;
    const urlparser = document.createElement('a');
    urlparser.href = course.meta_e_url;

    if (loading) {
      return (<span>Loading</span>);
    }

    return (
      <div style={{ paddingTop: '1rem' }}>
        <Row>
          <Col xs={12} sm={5}>
            <Panel header="Overview">
              <Table responsive>
                <tbody>
                  <tr>
                    <th>Course code</th>
                    <td>{course.course_id}</td>
                  </tr>
                  <tr>
                    <th>Course name</th>
                    <td>{course.name}</td>
                  </tr>
                  <tr>
                    <th>Credits</th>
                    <td>{course.credits}</td>
                  </tr>
                  <tr>
                    <th>Level</th>
                    <td>{course.meta_study_level_name}</td>
                  </tr>
                  <tr>
                    <th>University</th>
                    <td>{university.name}</td>
                  </tr>
                  <tr>
                    <th>Semester</th>
                    <td>{course.semester}</td>
                  </tr>
                  <tr>
                    <th>External URL</th>
                    <td>
                      <a href={`${course.meta_e_url}`} target="_blank">{course.course_id} at {urlparser.hostname}</a>
                    </td>
                  </tr>
                </tbody>
              </Table>
              { user.admin && <EditCourse /> }
            </Panel>
          </Col>

          <Col xs={12} sm={7} smOffset={0}>
            <h4 className="text-center">Dependency tree</h4>
            <div className={isGraphLoaded ? commonStyles.hidden : commonStyles.visible} >
              <Spinner />
            </div>
            <object
              type="image/svg+xml"
              data={course.plantuml_url}
              className="center-block"
              style={{ width: '100%', height: '100%' }}
              onLoad={() => this.handleImageLoaded()}
            />
            <br />
            <div className="text-center">
              <a
                href={course.plantuml_url}
                target="_blank"
                className={isGraphLoaded ? 'visible' : 'hidden'}
              >Open</a>
            </div>
          </Col>
        </Row>

        <Row style={{ paddingTop: '1rem' }}>
          <Col xs={12} sm={12}>
            <PreReqTable />
          </Col>
        </Row>

        <Row>
          <Col xs={12} sm={4} smOffset={0}>
            <Panel header="Course content">
              { course.meta_course_content ?
                <p>{course.meta_course_content}</p> :
                <p style={{ color: 'grey', fontSize: '15px' }}>This course has no course content specified</p>
              }
            </Panel>
          </Col>
          <Col xs={12} sm={4} smOffset={0}>
            <Panel header="Goals">
              { course.meta_goals ?
                <p>{course.meta_goals}</p> :
                <p style={{ color: 'grey', fontSize: '15px' }}>This course has no goals specified</p>
              }
            </Panel>
          </Col>
          <Col xs={12} sm={4} smOffset={0}>
            <Panel header="Activities and learning methods">
              { course.meta_learning_methods ?
                <p>{course.meta_learning_methods}</p> :
                <p style={{ color: 'grey', fontSize: '15px' }}>This course has no learning methods specified</p>
              }
            </Panel>
          </Col>
        </Row>
      </div>
    );
  }
}

GeneralTab.propTypes = {
  course: React.PropTypes.object,
  loading: React.PropTypes.bool,
  user: React.PropTypes.object,
};

const mapStateToProps = createStructuredSelector({
  course: selectCourse(),
  loading: selectCourseLoading(),
  user: selectAuthWrapper(),
});

export default connect(mapStateToProps)(GeneralTab);
