import React, { Component, PropTypes } from 'react';
import { Link } from 'react-router';
import { connect } from 'react-redux';

import Panel from 'react-bootstrap/lib/Panel';
import Table from 'react-bootstrap/lib/Table';
import Button from 'react-bootstrap/lib/Button';
import Glyphicon from 'react-bootstrap/lib/Glyphicon';
import FormGroup from 'react-bootstrap/lib/FormGroup';
import ControlLabel from 'react-bootstrap/lib/ControlLabel';
import Alert from 'react-bootstrap/lib/Alert';

import Modal from 'components/Modal';
import CourseSearch from 'containers/CourseSearch';
import { createStructuredSelector } from 'reselect';
import { selectCourse, selectRequestingAddPrereqSuccess } from './selectors';
import { requestAddPrereq, requestRemovePrereq } from './actions';
import selectAuthWrapper from '../AuthWrapper/selectors';


class PreReqTable extends Component {
  constructor() {
    super();
    this.state = {
      showForm: false,
      selectedCourse: null,
      selectionError: false,
    };
  }

  componentWillReceiveProps(next) {
    if (next.requestingAddPrereqSuccess) {
      this.setState({ showForm: false });
    }
  }

  getPanelFooter() {
    return (
      <div className="text-right">
        { this.props.user.admin &&
          <Button onClick={() => this.toggleModal(true)}>Add course</Button>
        }
      </div>
    );
  }

  getModal() {
    return (
      <Modal
        onDismiss={() => this.toggleModal(false)}
        onSubmit={(event) => this.handleAddCourse(event)}
        title="Add Prerequisite for course"
      >
        { (false) &&
          <Alert bsStyle="danger">
            <stong>Something went wrong, please try again later</stong>
          </Alert>
        }
        <FormGroup>
          <ControlLabel>Course ID</ControlLabel>
          <CourseSearch handleChange={(c) => this.handleCourseChange(c)} />
        </FormGroup>
      </Modal>
    );
  }

  handleRemoveCourse(course) {
    this.props.dispatch(requestRemovePrereq(this.props.course.id, course));
  }

  handleAddCourse(event) {
    event.preventDefault();
    const course = this.state.selectedCourse;

    if (!course) {
      return this.setState({ selectionError: true });
    }

    return this.props.dispatch(requestAddPrereq(this.props.course.id, course.id));
  }

  toggleModal(showForm) {
    this.setState({ showForm });
  }

  handleCourseChange(course) {
    this.setState({ selectedCourse: course });
  }

  render() {
    const { course, user } = this.props;
    const prereqs = course.children || [];
    return (
      <div>
        { this.state.showForm && this.getModal() }
        <Panel header="Prerequisites" footer={this.getPanelFooter()}>
          <Table responsive>
            <thead>
              <tr>
                <th>Course</th>
                <th>Credits</th>
                <th>Level</th>
                <th>Required</th>
                <th>Actions</th>
              </tr>
            </thead>
            <tbody>
              {prereqs.map((prereq, key) => (
                <tr key={key}>
                  <td>
                    <Link to={`/course/${prereq.university.short_name}/${prereq.course_id}`}>{prereq.course_id}</Link>
                  </td>
                  <td>{prereq.credits}</td>
                  <td>{prereq.meta_study_level_name}</td>
                  <td>{prereq.required ? 'Yes' : 'No'}</td>
                  <td>
                    { user.admin &&
                      <a style={{ cursor: 'pointer' }} onClick={() => this.handleRemoveCourse(prereq.id)}>
                        <Glyphicon glyph="remove-sign" />
                      </a>
                    }
                  </td>
                </tr>
              ))}
            </tbody>
          </Table>
        </Panel>
      </div>
    );
  }
}

PreReqTable.propTypes = {
  dispatch: PropTypes.func,
  course: PropTypes.object,
  user: PropTypes.object,
};

const mapStateToProps = createStructuredSelector({
  course: selectCourse(),
  requestingAddPrereqSuccess: selectRequestingAddPrereqSuccess(),
  user: selectAuthWrapper(),
});

export default connect(mapStateToProps)(PreReqTable);
