import React, { Component } from 'react';
import { connect } from 'react-redux';
import { createStructuredSelector } from 'reselect';

import Grid from 'react-bootstrap/lib/Grid';
import Row from 'react-bootstrap/lib/Row';
import Tab from 'react-bootstrap/lib/Tab';
import Tabs from 'react-bootstrap/lib/Tabs';
import PageHeader from 'react-bootstrap/lib/PageHeader';

import { loadCourse, loadSimilar } from './actions';
import {
  selectCourse,
  selectCourseLoading,
  selectCourseError,
  selectSimilarCourses,
} from './selectors';

import GeneralTab from './GeneralTab';
import CurriculumTab from './CurriculumTab';
import SimilarTab from './SimilarTab';
import ApproveTab from './ApproveTab';
import NotFoundPage from 'containers/NotFoundPage';
import Spinner from 'components/Spinner';


class CourseDetails extends Component {
  constructor() {
    super();

    this.state = { activeTab: 1 };
  }
  componentDidMount() {
    this.props.dispatch(loadCourse(this.props.params.id, this.props.params.university));
    this.props.dispatch(loadSimilar(this.props.params.id, this.props.params.university));
  }

  componentWillReceiveProps(nextProps) {
    if (this.props.params.id !== nextProps.params.id) {
      this.props.dispatch(loadCourse(nextProps.params.id, nextProps.params.university));
    }
  }

  render() {
    const { error, course } = this.props;

    if (error) {
      return (<NotFoundPage />);
    }

    return (
      <Grid>
        <Row>
          <PageHeader style={{ borderBottom: 'none' }}>
            {course.course_id}<small>{' '}{course.name}</small>
          </PageHeader>
        </Row>
        <Row>
          <Tabs
            activeKey={this.state.activeTab}
            onSelect={(t) => this.setState({ activeTab: t })}
            id="tablist"
          >
            <Tab eventKey={1} title="General">
              <GeneralTab />
            </Tab>
            <Tab eventKey={2} title="Curriculum">
              <CurriculumTab curriculum={course.curriculum || []} />
            </Tab>
            <Tab eventKey={3} title="Similar courses">
              {course.similarCourses.isLoading
              ?
                <Spinner />
              :
                <SimilarTab courses={course.similarCourses.data} />
              }
            </Tab>
            <Tab eventKey={4} title="Approved courses">
              <ApproveTab />
            </Tab>
          </Tabs>
        </Row>
      </Grid>
    );
  }
}

CourseDetails.propTypes = {
  params: React.PropTypes.object,
  dispatch: React.PropTypes.func,
  course: React.PropTypes.object,
  error: React.PropTypes.bool,
};

const mapStateToProps = createStructuredSelector({
  course: selectCourse(),
  loading: selectCourseLoading(),
  error: selectCourseError(),
  similarCourses: selectSimilarCourses(),
});

export default connect(mapStateToProps)(CourseDetails);
