import { fromJS } from 'immutable';
import {
  LOAD_COURSE,
  LOAD_COURSE_SUCCESS,
  LOAD_COURSE_FAILED,
  LOAD_SIMILAR_COURSES,
  LOAD_SIMILAR_COURSES_SUCCESS,
  LOAD_SIMILAR_COURSES_FAILED,
  REQUEST_ADD_PREREQ,
  REQUEST_ADD_PREREQ_SUCCESS,
  REQUEST_ADD_PREREQ_FAILED,
  REQUEST_REMOVE_PREREQ,
  REQUEST_REMOVE_PREREQ_SUCCESS,
  REQUEST_REMOVE_PREREQ_FAILED,
  REQUEST_ADD_APPROVED,
  REQUEST_ADD_APPROVED_SUCCESS,
  REQUEST_ADD_APPROVED_FAILED,
  REQUEST_REMOVE_APPROVED,
  REQUEST_REMOVE_APPROVED_SUCCESS,
  REQUEST_REMOVE_APPROVED_FAILED,
  REQUEST_UPDATE_COURSE,
  REQUEST_UPDATE_COURSE_SUCCESS,
  REQUEST_UPDATE_COURSE_FAILED,
} from './constants';

const initialState = fromJS({
  // Course
  loading: false,
  error: false,
  course: {},

  // Similar courses
  similarLoading: false,
  similarError: false,
  similarCourses: [],

  // Prerequisites
  requestingAddPrereq: false,
  requestingAddPrereqSuccess: false,
  requestingAddPrereqFailure: false,

  requestingRemovePrereq: false,
  requestingRemovePrereqSuccess: false,
  requestingRemovePrereqFailure: false,

  // Approved
  requestingAddApproved: false,
  requestingAddApprovedSuccess: false,
  requestingAddApprovedFailure: false,

  requestingRemoveApproved: false,
  requestingRemoveApprovedSuccess: false,
  requestingRemoveApprovedFailure: false,

  // Edit course
  requestingUpdateCourse: false,
  requestingUpdateCourseSuccess: false,
  requestingUpdateCourseFailure: false,
});

function courseDetailsReducer(state = initialState, action) {
  // Course
  switch (action.type) {
    case LOAD_COURSE:
      return state
        .set('loading', true)
        .set('course', {})
        .set('error', false);
    case LOAD_COURSE_SUCCESS:
      return state
        .set('loading', false)
        .set('error', false)
        .set('course', action.course);
    case LOAD_COURSE_FAILED:
      return state
        .set('loading', false)
        .set('error', true);

    // Similar courses
    case LOAD_SIMILAR_COURSES:
      return state
        .set('similarLoading', true)
        .set('similarError', false);
    case LOAD_SIMILAR_COURSES_SUCCESS:
      return state
        .set('similarLoading', false)
        .set('similarError', false)
        .set('similarCourses', state.get('similarCourses').concat(action.similar));
    case LOAD_SIMILAR_COURSES_FAILED:
      return state
        .set('similarLoading', false)
        .set('similarError', true);

    // Prerequisites
    case REQUEST_ADD_PREREQ:
      return state
        .set('requestingAddPrereq', true)
        .set('requestingAddPrereqFailure', false);
    case REQUEST_ADD_PREREQ_SUCCESS:
      return state
        .set('requestingAddPrereq', false)
        .set('requestingAddPrereqSuccess', true);
    case REQUEST_ADD_PREREQ_FAILED:
      return state
        .set('requestingAddPrereq', false)
        .set('requestingAddPrereqFailure', true);

    case REQUEST_REMOVE_PREREQ:
      return state
        .set('requestingRemovePrereq', true)
        .set('requestingRemovePrereqFailure', false);
    case REQUEST_REMOVE_PREREQ_SUCCESS:
      return state
        .set('requestingRemovePrereq', false)
        .set('requestingRemovePrereqSuccess', true);
    case REQUEST_REMOVE_PREREQ_FAILED:
      return state
        .set('requestingRemovePrereq', false)
        .set('requestingRemovePrereqFailure', true);

    // Approved
    case REQUEST_ADD_APPROVED:
      return state
        .set('requestingAddApproved', true)
        .set('requestingAddApprovedFailure', false);
    case REQUEST_ADD_APPROVED_SUCCESS:
      return state
        .set('requestingAddApproved', false)
        .set('requestingAddApprovedSuccess', true);
    case REQUEST_ADD_APPROVED_FAILED:
      return state
        .set('requestingAddApproved', false)
        .set('requestingAddApprovedFailure', true);

    case REQUEST_REMOVE_APPROVED:
      return state
        .set('requestingRemoveApproved', true)
        .set('requestingRemoveApprovedFailure', false);
    case REQUEST_REMOVE_APPROVED_SUCCESS:
      return state
        .set('requestingRemoveApproved', false)
        .set('requestingRemoveApprovedSuccess', true);
    case REQUEST_REMOVE_APPROVED_FAILED:
      return state
        .set('requestingRemoveApproved', false)
        .set('requestingRemoveApprovedFailure', true);

    // Edit course
    case REQUEST_UPDATE_COURSE:
      return state
        .set('requestingUpdateCourse', true)
        .set('requestingUpdateCourseFailure', false);
    case REQUEST_UPDATE_COURSE_SUCCESS:
      return state
        .set('requestingUpdateCourse', false)
        .set('requestingUpdateCourseSuccess', true);
    case REQUEST_UPDATE_COURSE_FAILED:
      return state
        .set('requestingUpdateCourse', false)
        .set('requestingUpdateCourseFailure', true);
    default:
      return state;
  }
}

export default courseDetailsReducer;
