import { takeLatest } from 'redux-saga';
import { take, call, put } from 'redux-saga/effects';

import api from 'utils/api';

import {
  LOAD_COURSE,
  LOAD_SIMILAR_COURSES,
  REQUEST_ADD_PREREQ,
  REQUEST_REMOVE_PREREQ,
  REQUEST_ADD_PREREQ_SUCCESS,
  REQUEST_REMOVE_PREREQ_SUCCESS,
  REQUEST_ADD_APPROVED,
  REQUEST_REMOVE_APPROVED,
  REQUEST_ADD_APPROVED_SUCCESS,
  REQUEST_REMOVE_APPROVED_SUCCESS,
  REQUEST_UPDATE_COURSE,
  REQUEST_UPDATE_COURSE_SUCCESS,
} from './constants';
import {
  courseLoaded,
  courseError,
  similarError,
  similarLoaded,
  requestAddPrereqSuccess,
  requestAddPrereqFailure,
  requestRemovePrereqSuccess,
  requestRemovePrereqFailure,
  requestAddApprovedSuccess,
  requestAddApprovedFailure,
  requestRemoveApprovedSuccess,
  requestRemoveApprovedFailure,
  requestUpdateCourseFailed,
  requestUpdateCourseSuccess,
} from './actions';

// Course
// TODO
export function* getCourse({ id, university }) {
  const res = yield call(api.getCourse, id, university);
  if (res.err) {
    return yield put(courseError());
  }
  return yield put(courseLoaded(res.data));
}

export function* getCourseWatcher() {
  yield takeLatest(LOAD_COURSE, getCourse);
}

// Similar courses
export function* getSimilarCourses({ id, university }) {
  const res = yield call(api.getSimilarCourses, id, university);
  if (res.err) {
    return yield put(similarError());
  }
  return yield put(similarLoaded(res.data.similar_courses.res));
}

export function* getSimilarCoursesWatcher() {
  yield takeLatest(LOAD_SIMILAR_COURSES, getSimilarCourses);
}

// Prerequisites
export function* addPreReq({ from, to }) {
  const res = yield call(api.addPreReq, from, to);
  if (res.err) {
    return yield put(requestAddPrereqFailure());
  }
  return yield put(requestAddPrereqSuccess(from));
}

export function* addPreReqWatcher() {
  const action = yield take(REQUEST_ADD_PREREQ);
  yield call(addPreReq, action);
}

export function* removePreReq({ from, to }) {
  const res = yield call(api.removePreReq, from, to);
  if (res.err) {
    return yield put(requestRemovePrereqFailure());
  }
  return yield put(requestRemovePrereqSuccess(from));
}

export function* removePreReqWatcher() {
  const action = yield take(REQUEST_REMOVE_PREREQ);
  yield call(removePreReq, action);
}

// TODO
export function* addPreReqSuccessWatcher() {
  yield takeLatest(REQUEST_ADD_PREREQ_SUCCESS, getCourse);
}
// TODO
export function* removePreReqSucessWatcher() {
  yield takeLatest(REQUEST_REMOVE_PREREQ_SUCCESS, getCourse);
}

// Approved
export function* addApproved({ from, to }) {
  const res = yield call(api.addApproved, from, to);
  if (res.err) {
    return yield put(requestAddApprovedFailure());
  }
  return yield put(requestAddApprovedSuccess(from));
}

export function* addApprovedWatcher() {
  const action = yield take(REQUEST_ADD_APPROVED);
  yield call(addApproved, action);
}

export function* removeApproved({ from, to }) {
  const res = yield call(api.removeApproved, from, to);
  if (res.err) {
    return yield put(requestRemoveApprovedFailure());
  }
  return yield put(requestRemoveApprovedSuccess(from));
}

export function* removeApprovedWatcher() {
  const action = yield take(REQUEST_REMOVE_APPROVED);
  yield call(removeApproved, action);
}

// TODO
export function* addApprovedSuccessWatcher() {
  yield takeLatest(REQUEST_ADD_APPROVED_SUCCESS, getCourse);
}
// TODO
export function* removeApprovedSucessWatcher() {
  yield takeLatest(REQUEST_REMOVE_APPROVED_SUCCESS, getCourse);
}

// Edit course
function* updateCourse({ course }) {
  const res = yield call(api.updateCourse, course);
  if (res.err) {
    return yield put(requestUpdateCourseFailed());
  }

  return yield put(requestUpdateCourseSuccess(course.id));
}

function* updateCourseWatcher() {
  yield takeLatest(REQUEST_UPDATE_COURSE, updateCourse);
}

// TODO
export function* updateCourseSuccessWatcher() {
  yield takeLatest(REQUEST_UPDATE_COURSE_SUCCESS, getCourse);
}

export default [
  getCourseWatcher,
  getSimilarCoursesWatcher,
  addPreReqWatcher,
  removePreReqWatcher,
  addPreReqSuccessWatcher,
  removePreReqSucessWatcher,
  addApprovedWatcher,
  removeApprovedWatcher,
  addApprovedSuccessWatcher,
  removeApprovedSucessWatcher,
  updateCourseWatcher,
  updateCourseSuccessWatcher,
];
