import React, { Component } from 'react';
import { connect } from 'react-redux';
import { createStructuredSelector } from 'reselect';
import { Link } from 'react-router';

import Col from 'react-bootstrap/lib/Col';
import Grid from 'react-bootstrap/lib/Grid';
import Row from 'react-bootstrap/lib/Row';
import Table from 'react-bootstrap/lib/Table';
import FormGroup from 'react-bootstrap/lib/FormGroup';
import FormControl from 'react-bootstrap/lib/FormControl';

import CreateCourseButton from 'containers/CreateCourse';
import CreateUniversityButton from 'containers/CreateUniversity';

import { loadCourseList } from './actions';

import {
  selectCourseList,
  selectCourseListLoading,
  selectCourseListError,
} from './selectors';

import selectAuthWrapper from '../AuthWrapper/selectors';


class CourseList extends Component {
  componentWillMount() {
    this.props.dispatch(loadCourseList(''));
  }

  getTableSection() {
    if (this.props.loading) {
      return (<span>Loading</span>);
    }
    if (this.props.error) {
      return (
        <span>
          Error getting courses. Is the server running?
        </span>
      );
    }

    if (this.props.courses) {
      const courses = this.props.courses.map((course, i) => (
        <tr key={i}>
          <td>
            <Link to={`/course/${course.university.short_name}/${course.course_id}`}>{course.course_id}</Link>
          </td>
          <td>
            <Link to={`/course/${course.university.short_name}/${course.course_id}`}>{course.name}</Link>
          </td>
          <td>
            <Link to={`/course/${course.university.short_name}/${course.course_id}`}>{course.university.name}</Link>
          </td>
        </tr>
      ));

      return (
        <Table responsive>
          <thead>
            <tr>
              <th>Course code</th>
              <th>Name</th>
              <th>University</th>
            </tr>
          </thead>
          <tbody>
            {courses}
          </tbody>
        </Table>
      );
    }
    return (<div />);
  }

  handleSearchChange(event) {
    this.props.dispatch(loadCourseList(event.target.value));
  }

  render() {
    return (
      <Grid>
        {this.props.user.admin &&
          <Row>
            <Col xs={3} xsOffset={2} sm={2} smOffset={2}>
              <CreateCourseButton />
            </Col>
            <Col xs={3} sm={2}>
              <CreateUniversityButton />
            </Col>
          </Row>
        }
        <Row>
          <Col xs={12} sm={8} smOffset={2}>
            <h2> Course List</h2>
            <FormGroup>
              <FormControl
                type="text"
                placeholder="Search"
                onChange={(e) => this.handleSearchChange(e)}
              />
            </FormGroup>
            {this.getTableSection()}
          </Col>
        </Row>
      </Grid>
    );
  }
}

CourseList.propTypes = {
  dispatch: React.PropTypes.func,
  courses: React.PropTypes.array,
  loading: React.PropTypes.bool,
  error: React.PropTypes.bool,
  user: React.PropTypes.object,
};

const mapStateToProps = createStructuredSelector({
  courses: selectCourseList(),
  loading: selectCourseListLoading(),
  error: selectCourseListError(),
  user: selectAuthWrapper(),
});

function mapDispatchToProps(dispatch) {
  return {
    loadCourses: (q) => dispatch(loadCourseList(q)),
    dispatch,
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(CourseList);
