import { call, put, take } from 'redux-saga/effects';
import { takeLatest } from 'redux-saga';

import api from 'utils/api';
import { LOAD_UNIVERSITY_LIST, REQUEST_CREATE_COURSE } from './constants';
import {
  universityListLoaded,
  loadUniversitiesFailed,
  requestCreateCourseSuccess,
  requestCreateCourseFailed,
} from './actions';


function* getUniversityList() {
  const res = yield call(api.getUniversityList);
  if (res.err) {
    return yield put(loadUniversitiesFailed());
  }

  return yield put(universityListLoaded(res.data.results));
}

function* getUniversityListWatcher() {
  yield takeLatest(LOAD_UNIVERSITY_LIST, getUniversityList);
}

function* createCourse({ course }) {
  const res = yield call(api.createCourse, course);
  if (res.err) {
    return yield put(requestCreateCourseFailed());
  }

  return yield put(requestCreateCourseSuccess(res.data.id));
}

function* createCourseWatcher() {
  const action = yield take(REQUEST_CREATE_COURSE);
  yield call(createCourse, action);
}

export default [
  getUniversityListWatcher,
  createCourseWatcher,
];
