import React, { Component, PropTypes } from 'react';
import { connect } from 'react-redux';
import { createStructuredSelector } from 'reselect';

import Button from 'react-bootstrap/lib/Button';
import Alert from 'react-bootstrap/lib/Alert';

import Modal from 'components/Modal';
import FieldGroup from 'components/FieldGroup';

import selectCreateUniversity from './selectors';
import { createUniversity } from './actions';

export class CreateUniversity extends Component {
  constructor() {
    super();
    this.state = { showForm: false };
  }

  componentWillReceiveProps(next) {
    if (next.createUniversity.success && this.state.showForm) {
      this.setState({ showForm: false });
    }
  }

  handleOnClick() {
    this.setState({ showForm: true });
  }

  handleModalDismiss() {
    this.setState({ showForm: false });
  }

  handleSubmit(event) {
    event.preventDefault();

    if (this.props.createUniversity.isCreating) {
      return;
    }

    this.props.dispatch(createUniversity({
      name: event.currentTarget.name.value.trim(),
      short_name: event.currentTarget.short_name.value.trim(),
    }));
  }

  render() {
    const { failure } = this.props.createUniversity;

    return (
      <div>
        <Button onClick={() => this.handleOnClick()}>Add University</Button>
        {this.state.showForm &&
          <Modal
            onDismiss={() => this.handleModalDismiss()}
            onSubmit={(event) => this.handleSubmit(event)}
            title="Create course"
          >
            { failure &&
              <Alert bsStyle="danger">
                <stong>Something went wrong, please try again later</stong>
              </Alert>
            }
            <FieldGroup
              type="text"
              label="Name"
              name="name"
              placeholder="Enter text"
            />
            <FieldGroup
              type="text"
              label="Short name"
              name="short_name"
              placeholder="Short name"
            />
          </Modal>
        }
      </div>

    );
  }
}

const mapStateToProps = createStructuredSelector({
  createUniversity: selectCreateUniversity(),
});

CreateUniversity.propTypes = {
  dispatch: PropTypes.func,
  createUniversity: PropTypes.object,
};


export default connect(mapStateToProps)(CreateUniversity);
