import React, { Component, PropTypes } from 'react';
import { connect } from 'react-redux';
import { Link } from 'react-router';


import Grid from 'react-bootstrap/lib/Grid';
import Row from 'react-bootstrap/lib/Row';
import Col from 'react-bootstrap/lib/Col';
import Table from 'react-bootstrap/lib/Table';

import { createStructuredSelector } from 'reselect';
import { loadSearchResults } from './actions';
import {
  selectSearchResultsLoading,
  selectSearchResultsError,
  selectSearchResults,
} from './selectors';

import Spinner from 'components/Spinner';

export class SimilarSearch extends Component {
  componentDidMount() {
    this.props.dispatch(loadSearchResults(this.props.location.query));
  }

  render() {
    const courses = this.props.courses || [];
    const isLoading = this.props.loading;
    const courseId = this.props.location.query.courseId;

    if (isLoading) {
      return <Spinner />;
    }
    return (
      <Grid>
        <Row>
          <Col xs={10} xsOffset={1} sm={10} smOffset={1} md={11} mdOffset={0} >
            <h1>Search results</h1>
            <Table responsive>
              <thead>
                <tr>
                  <th>Code</th>
                  <th>Name</th>
                  <th>University</th>
                  <th>Similarity score</th>
                </tr>
              </thead>
              <tbody>
                {courses.map((course, key) => (
                  <tr key={key}>
                    <td>
                      <Link to={`/course/${courseId}/compare/${course.id}`}>{course.code}</Link>
                    </td>
                    <td>
                      <Link to={`/course/${courseId}/compare/${course.id}`}>{course.name}</Link>
                    </td>
                    <td>
                      {course.university}
                    </td>
                    <td>
                      {parseFloat(course.score * 100).toFixed(2)}%
                    </td>
                  </tr>
                ))}
              </tbody>
            </Table>
          </Col>
        </Row>
      </Grid>
    );
  }
}

SimilarSearch.propTypes = {
  dispatch: PropTypes.func,
  location: PropTypes.object,
  courses: PropTypes.array,
  loading: PropTypes.bool,
};

const mapStateToProps = createStructuredSelector({
  courses: selectSearchResults(),
  loading: selectSearchResultsLoading(),
  error: selectSearchResultsError(),
});

export default connect(mapStateToProps)(SimilarSearch);
