import React, { Component, PropTypes } from 'react';
import { connect } from 'react-redux';
import { push } from 'react-router-redux';

import Grid from 'react-bootstrap/lib/Grid';
import Row from 'react-bootstrap/lib/Row';
import Col from 'react-bootstrap/lib/Col';
import Button from 'react-bootstrap/lib/Button';
import FormControl from 'react-bootstrap/lib/FormControl';
import FormGroup from 'react-bootstrap/lib/FormGroup';
import ControlLabel from 'react-bootstrap/lib/ControlLabel';
import Alert from 'react-bootstrap/lib/Alert';

import {
  selectUniversities,
  selectFetchingUniversities,
  selectFetchingUniversitiesError,
} from '../CreateCourse/selectors';
import { createStructuredSelector } from 'reselect';
import { loadUniversityList } from '../CreateCourse/actions';

import Spinner from 'components/Spinner';
import CourseSearch from 'containers/CourseSearch';

export class SimilarSearch extends Component {
  constructor() {
    super();
    this.state = {
      selectedCourse: null,
      selectionError: false,
    };
  }
  componentDidMount() {
    if (this.props.universities.length < 1) {
      this.props.dispatch(loadUniversityList());
    }
  }

  handleCourseChange(course) {
    this.setState({ selectedCourse: course });
  }

  handleSubmit(event) {
    event.preventDefault();
    const course = this.state.selectedCourse;
    if (!course) {
      return this.setState({ selectionError: true });
    }

    const to = event.currentTarget.toUniversity.value.trim();
    return this.props.dispatch(push(
      `/similar/results?courseId=${course.id}&toUniversity=${to}`
    ));
  }

  render() {
    const { universities, fetchingUniversities, fetchingUniversitiesError } = this.props;
    return (
      <Grid>
        <Row>
          <Col xs={10} xsOffset={1} sm={8} smOffset={2} md={6} mdOffset={3} >
            <h3>Find similar courses</h3>
            <br />
            { this.state.selectionError &&
              <Alert bsStyle="danger">
                <stong>No course selected</stong>
              </Alert>
            }
            {fetchingUniversitiesError &&
              <Alert bsStyle="danger">
                <stong>Something went wrong, please try again later</stong>
              </Alert>
            }

            {fetchingUniversities
              ?
                <Spinner />
              :
                <form onSubmit={(event) => this.handleSubmit(event)}>
                  <FormGroup>
                    <CourseSearch handleChange={(course) => this.handleCourseChange(course)} />
                  </FormGroup>
                  <FormGroup>
                    <ControlLabel>Find similar courses at university</ControlLabel>
                    <FormControl componentClass="select" name="toUniversity">
                      <option value="">select</option>
                      {universities.map((university, key) => (
                        <option value={university.short_name} key={key}>{university.name}</option>
                      ))}
                    </FormControl>
                  </FormGroup>
                  <Button
                    className="center-block"
                    bsStyle="primary"
                    bsSize="large"
                    type="submit"
                    block
                  >
                    Search
                  </Button>
                </form>
            }
          </Col>
        </Row>
      </Grid>
    );
  }
}

SimilarSearch.propTypes = {
  dispatch: PropTypes.func,
  universities: PropTypes.array,
  fetchingUniversities: PropTypes.bool,
  fetchingUniversitiesError: PropTypes.bool,
};

const mapStateToProps = createStructuredSelector({
  universities: selectUniversities(),
  fetchingUniversities: selectFetchingUniversities(),
  fetchingUniversitiesError: selectFetchingUniversitiesError(),
});

export default connect(mapStateToProps)(SimilarSearch);
