// These are the pages you can go to.
// They are all wrapped in the App component, which should contain the navbar etc
// See http://blog.mxstbr.com/2016/01/react-apps-with-pages for more information
// about the code splitting business
import { getAsyncInjectors } from 'utils/asyncInjectors';
import { authenticated } from 'containers/AuthWrapper';
import auth from 'utils/auth';

const errorLoading = (err) => {
  console.error('Dynamic page loading failed', err); // eslint-disable-line no-console
};

const loadModule = (cb) => (componentModule, authProtected = true) => {
  if (authProtected) {
    return cb(null, authenticated(componentModule.default));
  }
  return cb(null, componentModule.default);
};

export default function createRoutes(store) {
  // Create reusable async injectors using getAsyncInjectors factory
  const { injectReducer, injectSagas } = getAsyncInjectors(store);

  return [
    {
      path: '/',
      name: 'startPage',
      getComponent(location, cb) {
        System.import('containers/StartPage')
          .then(loadModule(cb))
          .catch(errorLoading);
      },
    },
    {
      path: '/list',
      name: 'home',
      getComponent(nextState, cb) {
        const importHomeModules = Promise.all([
          System.import('containers/CourseList/reducers'),
          System.import('containers/CourseList/sagas'),
          System.import('containers/CourseList'),
        ]);

        const renderRoute = loadModule(cb);

        importHomeModules.then(([reducer, sagas, component]) => {
          injectReducer('courseList', reducer.default);
          injectSagas(sagas.default);
          renderRoute(component);
        });

        importHomeModules.catch(errorLoading);
      },
    },
    {
      path: '/course/:university/:id',
      name: 'courseDetails',
      getComponent(nextState, cb) {
        const importModules = Promise.all([
          System.import('containers/CourseDetails/reducers'),
          System.import('containers/CourseDetails/sagas'),
          System.import('containers/CourseDetails'),
        ]);

        const renderRoute = loadModule(cb);

        importModules.then(([reducer, sagas, component]) => {
          injectReducer('courseDetails', reducer.default);
          injectSagas(sagas.default);
          renderRoute(component);
        });

        importModules.catch(errorLoading);
      },
    },
    {
      path: '/similar',
      name: 'similarSearch',
      getComponent(location, cb) {
        System.import('containers/SimilarSearch')
          .then(loadModule(cb))
          .catch(errorLoading);
      },
    },
    {
      path: '/compare',
      name: 'compareDirectly',
      getComponent(location, cb) {
        System.import('containers/CompareDirectly')
          .then(loadModule(cb))
          .catch(errorLoading);
      },
    },
    {
      path: '/similar/results',
      name: 'searchResults',
      getComponent(nextState, cb) {
        const importModules = Promise.all([
          System.import('containers/SearchResults/reducers'),
          System.import('containers/SearchResults/sagas'),
          System.import('containers/SearchResults'),
        ]);

        const renderRoute = loadModule(cb);

        importModules.then(([reducer, sagas, component]) => {
          injectReducer('searchResults', reducer.default);
          injectSagas(sagas.default);
          renderRoute(component);
        });

        importModules.catch(errorLoading);
      },
    },
    {
      path: '/oauth/callback',
      name: 'oauthCallbackPage',
      onEnter: (nextState, replaceState) => {
        auth.jso.callback(null, () => {
          replaceState(window.localStorage.getItem('prevUrl') || '/');
        });
      },
    },

    {
      path: '/logout',
      name: 'logoutPage',
      onEnter: () => {
        auth.jso.wipeTokens();
        window.location = 'https://auth.dataporten.no/logout';
      },
    },
    {
      path: '/course/:id1/compare/:id2',
      name: 'compareCourses',
      getComponent(nextState, cb) {
        const importModules = Promise.all([
          System.import('containers/CompareCourses/reducers'),
          System.import('containers/CompareCourses/sagas'),
          System.import('containers/CompareCourses'),
        ]);

        const renderRoute = loadModule(cb);

        importModules.then(([reducer, sagas, component]) => {
          injectReducer('compareCourses', reducer.default);
          injectSagas(sagas.default);
          renderRoute(component);
        });

        importModules.catch(errorLoading);
      },
    },
    {
      path: '/course/:id1/compare/:id2',
      name: 'compareCourses',
      getComponent(nextState, cb) {
        const importModules = Promise.all([
          System.import('containers/CompareCourses/reducers'),
          System.import('containers/CompareCourses/sagas'),
          System.import('containers/CompareCourses'),
        ]);

        const renderRoute = loadModule(cb);

        importModules.then(([reducer, sagas, component]) => {
          injectReducer('compareCourses', reducer.default);
          injectSagas(sagas.default);
          renderRoute(component);
        });

        importModules.catch(errorLoading);
      },
    },
    {
      path: '*',
      name: 'notfound',
      getComponent(nextState, cb) {
        System.import('containers/NotFoundPage')
          .then(loadModule(cb))
          .catch(errorLoading);
      },
    },
  ];
}
