import request from './request';
import auth from './auth';

const API_BASE_URL = 'http://localhost:8000';

function getAuthHeader() {
  const token = auth.getToken();
  return {
    Authorization: `Bearer ${token.access_token}`,
  };
}

function getUserData() {
  const headers = getAuthHeader();
  return request('https://groups-api.dataporten.no/groups/me/groups', { headers });
}

function getCourseList(query) {
  return request(`${API_BASE_URL}/v1/courses/search/?q=${query}`);
}

function getCourse(id, university) {
  if (!university) {
    return request(`${API_BASE_URL}/v1/courses/${id}`);
  }
  return request(`${API_BASE_URL}/v1/university_courses/${university}/${id}`);
}

function getSimilarCourses(id, university) {
  return request(`${API_BASE_URL}/v1/university_courses/${university}/${id}/find_similar/`);
}

function createCourse(course) {
  const options = {
    headers: {
      Accept: 'application/json',
      'Content-Type': 'application/json',
      ...getAuthHeader(),
    },
    method: 'post',
    body: JSON.stringify(course),
  };
  return request(`${API_BASE_URL}/v1/courses/`, options);
}

function updateCourse(course) {
  const options = {
    headers: {
      Accept: 'application/json',
      'Content-Type': 'application/json',
      ...getAuthHeader(),
    },
    method: 'put',
    body: JSON.stringify(course),
  };
  return request(`${API_BASE_URL}/v1/courses/${course.id}/`, options);
}

function getUniversityList() {
  return request(`${API_BASE_URL}/v1/universities/`);
}

function createUniversity(university) {
  const options = {
    headers: {
      Accept: 'application/json',
      'Content-Type': 'application/json',
      ...getAuthHeader(),
    },
    method: 'post',
    body: JSON.stringify(university),
  };
  return request(`${API_BASE_URL}/v1/universities/`, options);
}

function addPreReq(from, to) {
  const headers = getAuthHeader();
  return request(`${API_BASE_URL}/v1/courses/${from}/add_prerequisite/${to}/`, { headers });
}

function removePreReq(from, to) {
  const headers = getAuthHeader();
  return request(`${API_BASE_URL}/v1/courses/${from}/remove_prerequisite/${to}/`, { headers });
}

function addApproved(from, to) {
  const headers = getAuthHeader();
  return request(`${API_BASE_URL}/v1/courses/${from}/approve/${to}/`, { headers });
}

function removeApproved(from, to) {
  const headers = getAuthHeader();
  return request(`${API_BASE_URL}/v1/courses/${from}/remove_approved/${to}/`, { headers });
}

function getCompareResult(id1, id2) {
  return request(`${API_BASE_URL}/v1/courses/${id1}/compare/${id2}/`);
}

function getSearchResults(courseId, toUniversity) {
  return request(`${API_BASE_URL}/v1/courses/${courseId}/find_similar/${toUniversity}/`);
}

export default {
  getUserData,
  getCourseList,
  getCourse,
  getSimilarCourses,
  createCourse,
  updateCourse,
  getUniversityList,
  createUniversity,
  addPreReq,
  removePreReq,
  addApproved,
  removeApproved,
  getCompareResult,
  getSearchResults,
};
